SIMPLER_ANIMAL_SETUP("peppino", "WAIT", "ROLL", "SPNG", "RIDE", "EDGE", "FALL", "SPDA", "DASH", "JOGG", "CAZY", "LAND", "DVBM", "SKDD", "DRLF", "DRRF") -- Initiate character and custom Sprite2s.

local helpers = _G["SIMPLER_ANIMAL_HELPERS"]

freeslot("sfx_mach1", "sfx_mach2", "sfx_mach3", "sfx_mach4")

function SIMPLER_ANIMAL_HOOKS.peppino_hook(mobj)
	if helpers.getSkin(mobj) == "peppino" then
		local player = helpers.getPlayer(mobj)
		local machtwospeed = (K_GetKartSpeed(player, false, true) * 12) / 20
		local machthreespeed = (K_GetKartSpeed(player, false, true) * 15) / 20
		local machfourspeed = (K_GetKartSpeed(player, false, true) * 30) / 20
		local speedthreshold = player.mo.scale / 8

		for i = 0, 108 do
			S_StopSoundByID(mobj, sfx_krta00 + i) -- Stop engine sounds.
		end

		if mobj.sprite2 == SPR2_GOAL then
			return
		elseif (mobj.sprite2 == SPR2_SPIN) then return "SPIN", A, A, B
		elseif (mobj.sprite2 == SPR2_DEAD) return "DEAD", A, A, C
		elseif mobj.sprite2 == SPR2_STIL then return "STIN", A, A, T -- https://git.do.srb2.org/KartKrew/RingRacers/-/issues/151
		elseif player.spindash then return "ROLL", A, A, L -- Spindash, start at A, loop back to A after C.
		elseif player.rideroid or player.pullup or player.dlzrocket then return "FALL", A, A, C
		elseif player.respawn.timer then
			helpers.SquaredSlow(mobj, -1)
			return "FALL", A, A, C
		elseif helpers.isTricking(mobj) then
			helpers.SquaredSlow(mobj, -1)
			return "FALL", A, A, C
		elseif (player.cmd.buttons & BT_BRAKE) and helpers.isMovingForward(mobj) and not helpers.isAirborne(mobj) then
			helpers.SquaredSlow(mobj, -1)
			return "SKDD", A, A, C
		elseif player.fastfall and ((player.speed >= machthreespeed) and (player.speed >= (player.lastspeed - speedthreshold))) then
			helpers.SquaredSlow(mobj, -1)
			return "LAND", A, A, C
		elseif player.fastfall then
			return "DVBM", A, A, H
		elseif (mobj.sprite2 == SPR2_DRLN or mobj.sprite2 == SPR2_DRRN) and helpers.isAirborne(mobj) then -- Slowable drift.
			helpers.SquaredSlow(mobj, -1)
			return "DRLF", A, A, C
		elseif (mobj.sprite2 == SPR2_DRLN or mobj.sprite2 == SPR2_DRRN) then -- Slowable drift.
			helpers.SquaredSlow(mobj, -1)
			return "DRLN", E, M, M
		elseif helpers.isAirborne(mobj) then
			helpers.SquaredSlow(mobj, -1)
			return "FALL", A, A, C
		elseif ((player.speed >= machfourspeed) and (player.speed >= (player.lastspeed - speedthreshold))) then
			helpers.SquaredSlow(mobj, -1)
			return "CAZY", A, A, H
		elseif ((player.speed >= machthreespeed) and (player.speed >= (player.lastspeed - speedthreshold))) then
			helpers.SquaredSlow(mobj, -1)
			return "FSTN", A, A, C
		elseif ((player.speed >= machtwospeed) and (player.speed >= (player.lastspeed - speedthreshold))) then
			helpers.SquaredSlow(mobj, -1)
			return "JOGG", A, A, H
		elseif mobj.sprite2 == SPR2_SLWN then
			if helpers.isMovingForward(mobj) then
				helpers.SquaredSlow(mobj, -1)
				return "SLWN", A, A, L
			else -- Moving sideways/backwards.
				if helpers.isMovingBackward(mobj) then
					helpers.SquaredSlow(mobj, 1)
					return "SLWN", L, L, A
				end
			end
		end
	end
end
